@@ -31,39 +31,39 @@ class RallyAPIClient(object):
         defects = Defect.get_all_in_kanban_state(kanban_state)
         return {'stories': stories, 'defects': defects}
 
-    def get_story_by_name(self, story_name):
+    def get_story_by_formatted_id(self, story_id):
         """
-        Return the story with the name ``story_name``.
+        Return the story with the id ``story_id``.
 
-        :param story_name:
+        :param story_id:
             The USXXX story id of the story.
 
         :returns:
             A ``Story`` object.
         """
-        return Story.get_by_name(story_name)
+        return Story.get_by_formatted_id(story_id)
 
-    def get_defect_by_name(self, defect_name):
+    def get_defect_by_formatted_id(self, defect_id):
         """
-        Return the defect with the name ``defect_name``.
+        Return the defect with the id ``defect_id``.
 
-        :param defect_name:
+        :param defect_id:
             The DEXXX defect id of the defect.
 
         :returns:
             A ``Defect`` object.
         """
-        return Defect.get_by_name(defect_name)
+        return Defect.get_by_formatted_id(defect_id)
 
-    def get_entity_by_name(self, entity_name):
+    def get_entity_by_formatted_id(self, entity_id):
         """
-        Return the entity with the name ``entity_name``.
+        Return the entity with the id ``entity_id``.
 
-        :param entity_name:
+        :param entity_id:
             The YYXXX id of the story/defect/task.
 
         :returns:
             A ``BaseRallyModel`` inheritted object, or None if no artifacts
             could be found.
         """
-        return Artifact.get_by_name(entity_name)
+        return Artifact.get_by_formatted_id(entity_id)
