@@ -130,6 +130,15 @@ class BaseRallyModel(object):
                 return self._full_sub_objects[attr_name]
             return object.__getattribute__(self, attr_name)
 
+    @classmethod
+    def set_cache_timeout(cls, timeout):
+        """Set the cache timeout for this object type.
+
+        :param timeout:
+            The timeout to set against this object type.
+        """
+        get_accessor().set_cache_timeout(cls.rally_name, timeout)
+
     @classmethod
     def create_from_ref(cls, reference):
         """Create an instance of ``cls`` by getting data for ``reference``.
@@ -235,7 +244,11 @@ class BaseRallyModel(object):
 
         url = "{0}.js?{1}pagesize=100&start={2}&fetch=true".format(
                         cls.rally_name.lower(), query_arg, start_index)
+        import time
+        s=  time.time()
         query_result_dict = get_accessor().make_api_call(url)
+        s2 = time.time()
+        print s2-s
         if query_result_dict['QueryResult']['Errors']:
             raise Exception('Errors in query: {0}'.format(
                              query_result_dict['QueryResult']['Errors']))
@@ -270,23 +283,23 @@ class BaseRallyModel(object):
         return converted_results
 
     @classmethod
-    def get_by_name(cls, name):
-        """Return all the objects by the given name.
+    def get_by_formatted_id(cls, formatted_id):
+        """Return all the objects by the given formatted_id.
 
         :param name:
             The name to search for. The get is performed by setting
-            FormattedID=``name`` in the url.
+            FormattedID=``formatted_id`` in the url.
 
         :returns:
             A single :py:class:`~pyrally.models.BaseRallyModel` inheriting
-            object with the FormattedID = name. Or ``None`` if one cannot
-            be found.
+            object with the FormattedID = formatted_id. Or ``None`` if one
+            cannot be found.
         """
-        clauses = ['FormattedID = "{0}"'.format(name)]
+        clauses = ['FormattedID = "{0}"'.format(formatted_id)]
         all_objects = cls.get_all(clauses)
         # Strangely, this returns for us444: de444, ta444 and us444.
         for obj in all_objects:
-            if obj.FormattedID.lower() == name.lower():
+            if obj.FormattedID.lower() == formatted_id.lower():
                 return obj
         return None
 
@@ -341,6 +354,7 @@ class BaseRallyModel(object):
                                  response['CreateResult']['Errors']))
             reference = response['CreateResult']['Object']['_ref']
             if refresh:
+                self.delete_from_cache()
                 new_data = get_accessor().make_api_call(reference, True)
                 self.rally_data = new_data[self.rally_name]
         return response
@@ -356,6 +370,11 @@ class BaseRallyModel(object):
         if response['OperationResult']['Errors']:
             raise Exception('Errors in delete: {0}'.format(
                                  response['OperationResult']['Errors']))
+        self.delete_from_cache()
+
+    def delete_from_cache(self):
+        """Remove this item from the cache"""
+        get_accessor().delete_from_cache(self.rally_name, self.ref)
 
 
 class Artifact(BaseRallyModel):
@@ -380,7 +399,7 @@ class Task(BaseRallyModel):
         return cls.get_all(clauses)
 
 
-class Story(BaseRallyModel):
+class HierarchicalRequirement(BaseRallyModel):
     rally_name = 'HierarchicalRequirement'
     sub_objects_dynamic_loader = {'tasks': 'Tasks', 'children': 'Children'}
 
@@ -424,3 +443,22 @@ class User(BaseRallyModel):
 
 class Iteration(BaseRallyModel):
     rally_name = 'Iteration'
+
+
+class Project(BaseRallyModel):
+    rally_name = 'Project'
+
+
+class Workspace(BaseRallyModel):
+    rally_name = 'Workspace'
+
+
+class Release(BaseRallyModel):
+    rally_name = 'Release'
+
+
+class TestCase(BaseRallyModel):
+    rally_name = 'TestCase'
+
+# Aliases
+Story = HierarchicalRequirement
